@@ -496,6 +496,7 @@ class ConfigType(hp.Transactionable):
 			if len(defaults) == 0:
 				raise MissingConfigError(item)
 			val, *defaults = defaults
+			line = []
 		else:
 			val = self[item]
 
@@ -565,7 +566,7 @@ class ConfigType(hp.Transactionable):
 			
 			return itr
 		
-		if isinstance(val, dict):
+		if isinstance(val, ConfigDict):
 			if '_type' in val:
 				
 				# val.push('__origin_key', item, silent=True)
@@ -610,7 +611,7 @@ class ConfigType(hp.Transactionable):
 				val = terms
 
 
-		elif isinstance(val, list):
+		elif isinstance(val, ConfigList):
 			
 			self._record_action('pull-list', suffix=item, val=val, silent=silent, **record_flags)
 			terms = []
@@ -721,9 +722,10 @@ class ConfigType(hp.Transactionable):
 		if exists and not overwrite:
 			return self._pull(key, silent=True)
 		
-		if exists and isinstance(val, str) and val == '_x_':
-			self._record_action('removing', suffix=key, val=val, silent=silent)
-			del self[key]
+		if isinstance(val, str) and val == '_x_':
+			if exists:
+				self._record_action('removing', suffix=key, val=val, silent=silent)
+				del self[key]
 			return
 		
 		val = configurize(val)
@@ -1050,6 +1052,13 @@ class ConfigList(ConfigType, hp.tlist):
 		super().__init__(*args, **kwargs)
 		self._empty_fill_value = empty_fill_value
 
+	def __repr__(self):
+		info = '[[' + ', '.join(f'{k}' for k in self) + ']]'
+		return f'[{hex(id(self))}]{info}'
+
+	def __str__(self):
+		return '[[' + ', '.join(f'{k}' for k in self) + ']]'
+
 	def purge_volatile(self):
 		'''
 		Recursively remove any items where the key starts with "__"
@@ -1165,7 +1174,7 @@ class Config_Iter:
 		# self._name = config._ident
 		# assert '_elements' in config, 'No elements found'
 		if elements is None:
-			elements = origin._elements
+			elements = origin['_elements']
 		self._elms = elements
 		
 		self._keys = [k for k in self._elms.keys()
@@ -1182,6 +1191,8 @@ class Config_Iter:
 		'''Find the next index or key'''
 		
 		if self._keys is None:
+			if not self._elms.contains_nodefault(self._idx):
+				raise StopIteration
 			return str(self._idx)
 		
 		while self._idx < len(self._elms):
@@ -1195,9 +1206,10 @@ class Config_Iter:
 		
 	def view(self):
 		'''Returns the next object without processing the item, may throw a StopIteration exception'''
-		obj = self._elms[self._next_idx()]
+		idx = self._next_idx()
+		obj = self._elms[idx]
 		if isinstance(obj, ConfigType):
-			return self._elms.sub(self._next_idx())
+			return self._elms.sub(idx)
 		return obj
 
 	def __next__(self):
